<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>erro</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Houve um erro ao escrever para o ficheiro seleccionado.</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sailcut</source>
        <translation type="obsolete">Sailcut</translation>
    </message>
    <message>
        <source>Sail corners coordinates</source>
        <translation type="unfinished">Coordenadas dos punhos da vela</translation>
    </message>
    <message>
        <source>tack</source>
        <translation type="unfinished">amura</translation>
    </message>
    <message>
        <source>clew</source>
        <translation type="unfinished">escota</translation>
    </message>
    <message>
        <source>head</source>
        <translation type="unfinished">gurutil</translation>
    </message>
    <message>
        <source>peak</source>
        <translation type="unfinished">pena</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation type="unfinished">Larguras IRC</translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Definição da vela</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Forma da vela</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Profundidade do topo</translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Profundidade do meio</translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Profundidade da esteira</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Ângulo de torção</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Ângulo de escota</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>graus</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Dimensões da vela</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Posição da curva</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Comprimento da testa</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Comprimento da esteira</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Comprimento da valuma</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Comprimento do gurutil</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Curva da valuma</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Curva da testa</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Curva da esteira</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Curva do gurutil</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Âgulo da testa com o gurutil</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonal</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Área vélica</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Calcular</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Corte de meia esquadria</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Corte transversal</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Corte &quot;twist foot&quot;</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Corte horizontal</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Número de secções</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Número de radiais</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Corte radial</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Corte vertical</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>Tecido</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Largura do tecido</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Baínha da valuma</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Outras baínhas</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Largura da costura</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Geometria do aparelho</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Altura do triângulo de vante - I</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Caimento do mastro/testa</translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>Base do triângulo de vante - J</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Distância do punho da amura à proa</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Altura do punho da amura</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Comprimento do barco fora-a-fora - LOA</translation>
    </message>
    <message>
        <source>Sail ID </source>
        <translation>ID da vela</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Vela Grande</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Vela de estai</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Número de radiais da testa</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation>Ângulo diedro</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Asa</translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation>Identificação da vela</translation>
    </message>
    <message>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Manual do Sailcut CAD</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Abrir &amp;recente</translation>
    </message>
    <message>
        <source>data</source>
        <translation>dados</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>desenho</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">desenvolvimento</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Imprimir</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Salvar &amp;como</translation>
    </message>
    <message>
        <source>to &amp;DXF</source>
        <translation>para &amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>para vela &amp;TXT</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>para vela &amp;XML</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>E&amp;xportar vela 3D</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>para &amp;Carlson plotter</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Exportar &amp;desenvolvimento</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Sa&amp;ir</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensões</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>&amp;Molde</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>&amp;Reforços</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>&amp;Aparelho</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Linguagem</translation>
    </message>
    <message>
        <source>Sailcut &amp;Handbook</source>
        <translation>&amp;Manual do Sailcut</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut</source>
        <translation>Acerca de &amp;Sailcut</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>Vista sombreada</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation>vista em grelha</translation>
    </message>
    <message>
        <source>development</source>
        <translation>desenvolvimento</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>carregado &apos;%1&apos;</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation>criada nova vela</translation>
    </message>
    <message>
        <source>About Sailcut</source>
        <translation>Acerca do Sailcut</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>erro ao carregar &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Sailcut data sheet</source>
        <translation>Folha de dados do Sailcut</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Tipo de vela</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Vela Grande</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Vela de Estai</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Formato da vela</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Corte Transversal</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Corte Horizontal</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Corte Radial</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Corte &quot;Twist foot&quot;</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Corte Vertical</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Corte de Meia Esquadria</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation> secções,   </translation>
    </message>
    <message>
        <source> head gores.</source>
        <translation type="obsolete"> paineis do topo.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation>Aparelho </translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Comprimento do barco fora-a-fora - LOA</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Altura do triângulo de vante - I</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Base do triângulo de vante - J</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Posição do punho da amura X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Altura do punho da amura Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Dimensões da vela</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Comprimento da testa</translation>
    </message>
    <message>
        <source>Mast rake</source>
        <translation type="obsolete">Caimento do mastro</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Âgulo da gurutil wrt testa</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Comprimento do gurutil</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Comprimento da esteira</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Comprimento da valuma</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation>Forma das extremidades</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Curva da testa</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Curva da gurutil</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Curva da valuma</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Curva da esteira</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Posição da curva da testa</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Posição da curva do gurutil</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Posição da curva da valuma</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Posição da curva da esteira</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Afinações da vela</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Âgulo de torção</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Âgulo de escota</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Costuras e baínhas do tecido</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Largura do tecido</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Largura das costuras</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Largura da baínha da valuma</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation>Largura de outras baínhas</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Molde da vela</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Factor da testa</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Profundidade</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Factor da valuma</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Perfil do topo</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Perfil do meio em h = </translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Perfil da base</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erro</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Houve um erro na impressão de dados</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>Houve um erro na impressão do desenvolvimento</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Houve um erro na impressão do desenho</translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>Escreveu &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Houve um erro ao escrever para o ficheiro seleccionado</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation>Radiais da pena,</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Caimento mastro/testa</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Asa</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation>Radiais da testa.</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>graus</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation type="unfinished">para formato de Traçar à &amp;mão</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>Top profile</source>
        <translation>Perfil do topo</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Perfil do meio</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Perfil da base</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Molde da vela</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Repartição vertical</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation>Aparelho</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>&amp;Definição da vela</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>&amp;vela 3D</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>&amp;Adicionar vela</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>A&amp;brir</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Abrir &amp;recente</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Salvar &amp;Como</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erro</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Houve um erro ao escrever para o ficheiro seleccionado</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Informação da vela</translation>
    </message>
    <message>
        <source>file</source>
        <translation>ficheiro</translation>
    </message>
    <message>
        <source>name</source>
        <translation>nome</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erro</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Houve um erro ao ler do ficheiro seleccionado.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Este sistema não tem suporte OpenGL</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Mostrar parâmetros</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>elevação</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>azimute</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controlos</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>Reiniciar vista</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Etiquetar</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Aumentar zoom</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Reduzir zoom</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>graus</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>Luff shape</source>
        <translation>Forma da testa</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Profundidade</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Forma da valuma</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>erro</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation type="unfinished">Houve um erro ao ler do ficheiro seleccionado.</translation>
    </message>
</context>
</TS>
